﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Calendar;
using System.Windows.Data;

namespace CalendarSelectors
{
	public partial class MainPage : UserControl
	{
		public MainPage()
		{
			InitializeComponent();
		}

		private void Button_Click(object sender, RoutedEventArgs e)
		{
			var eventsCollection = this.Resources["EventsList"] as EventsCollection;
			eventsCollection.Add(new Event { Date = DateTime.Today });
		}
	}

	public class CalendarViewModel : ViewModelBase
	{
		public CalendarViewModel()
		{

		}

		public EventsCollection Appointments
		{
			get;
			set;
		}
	}
		

	public class EventDayStyleSelector : StyleSelector
	{
		public Style EventStyle { get; set; }

		public override Style SelectStyle(object item, DependencyObject container)
		{
			var content = item as CalendarButtonContent;

			foreach (Event e in this.EventsCollection)
			{
				if (e.Date == content.Date)
				{
					return this.EventStyle;
				}
			}

			return base.SelectStyle(item, container);
		}

		private EventsCollection _eventsCollection;
		public EventsCollection EventsCollection
		{
			get
			{
				return this._eventsCollection;
			}
			set
			{
				if (this._eventsCollection != value)
				{
					if (this._eventsCollection != null)
					{
						this._eventsCollection.CollectionChanged -= this.OnCollectionChanged;
					}

					if (value != null)
					{
						value.CollectionChanged += this.OnCollectionChanged;
					}
					this._eventsCollection = value;
				}
			}
		}

		private void OnCollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
		{

		}
	}

	public class EventsCollection : ObservableCollection<Event> { }

	public class Event : INotifyPropertyChanged
	{
		public Event()
		{
			_date = DateTime.Now;
		}

		public int Day
		{
			get
			{
				return this.Date.Day;
			}
			set
			{
				DateTime today = DateTime.Now;
				this.Date = new DateTime(today.Year, today.Month, value);
			}
		}

		private DateTime _date;
		public DateTime Date
		{
			get
			{
				return this._date;
			}
			set
			{
				if (this._date != value)
				{
					this._date = value;
					this.FormatedDate = value.ToString("dddd, MMMM dd");
					this.OnPropertyChanged("Date");
					this.OnPropertyChanged("Day");
				}
			}
		}

		private string _formatedDate;
		public string FormatedDate
		{
			get
			{
				return this._formatedDate;
			}
			protected set
			{
				if (this._formatedDate != value)
				{
					this._formatedDate = value;
					this.OnPropertyChanged("FormatedDate");
				}
			}
		}

		private string _title;
		public string Title
		{
			get
			{
				return this._title;
			}
			set
			{
				if (this._title != value)
				{
					this._title = value;
					this.OnPropertyChanged("Title");
				}
			}
		}

		private string _company;
		public string Company
		{
			get
			{
				return this._company;
			}
			set
			{
				if (this._company != value)
				{
					this._company = value;
					this.OnPropertyChanged("Company");
				}
			}
		}

		private string _description;
		public string Description
		{
			get
			{
				return this._description;
			}
			set
			{
				if (this._description != value)
				{
					this._description = value;
					this.OnPropertyChanged("Description");
				}
			}
		}

		private Brush _brush;
		public Brush Brush
		{
			get
			{
				return this._brush;
			}
			set
			{
				this._brush = value;
				this.OnPropertyChanged("Brush");
			}
		}

		protected void OnPropertyChanged(string propertyName)
		{
			if (this.PropertyChanged != null)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}
		public event PropertyChangedEventHandler PropertyChanged;
	}
}
